@@ -4,7 +4,7 @@ const RE_DEPENDENCIES = /Dependencies\s+[/a-z]+\s*:\s/gm
 const RE_CHECKLIST = /#{3}\s+Checklist\s+(?:^-\s+\[x]\s+.+?(?:\n|\r\n|$)){2}/gm
 
 function bugReportBody(creator, content, hash) {
-	if (RE_CHECKLIST.test(content) && new RegExp(` \\(${hash}[a-z]? `).test(content)) {
+	if (RE_DEPENDENCIES.test(content) && RE_CHECKLIST.test(content) && new RegExp(` \\(${hash}[a-f0-9]? `).test(content)) {
 		return null
 	}
 
@@ -12,7 +12,7 @@ function bugReportBody(creator, content, hash) {
 
 - The bug can still be reproduced on the [newest nightly build](https://yazi-rs.github.io/docs/installation/#binaries).
 - The debug information (\`yazi --debug\`) is updated for the newest nightly.
-- The *required* fields in the checklist are checked.
+- The non-optional items in the checklist are checked.
 
 Issues with \`${LABEL_NAME}\` will be marked ready once edited with the proper content, or closed after 2 days of inactivity.
 `
@@ -27,7 +27,7 @@ function featureRequestBody(creator, content) {
 
 - The requested feature does not exist in the [newest nightly build](https://yazi-rs.github.io/docs/installation/#binaries).
 - The debug information (\`yazi --debug\`) is updated for the newest nightly.
-- The *required* fields in the checklist are checked.
+- The non-optional items in the checklist are checked.
 
 Issues with \`${LABEL_NAME}\` will be marked ready once edited with the proper content, or closed after 2 days of inactivity.
 `
@@ -61,10 +61,49 @@ module.exports = async ({ github, context, core }) => {
 		}
 	}
 
+	async function lastLabeledAt(id) {
+		try {
+			const { data: events } = await github.rest.issues.listEvents({
+				...context.repo,
+				issue_number: id,
+				per_page    : 100,
+			})
+
+			const all = events.filter(v => v.event === "labeled" && v.label?.name === LABEL_NAME)
+			return all.at(-1)?.created_at
+		} catch (e) {
+			core.error(`Error getting label timestamp: ${e.message}`)
+			return null
+		}
+	}
+
+	async function removedLabelManually(id) {
+		try {
+			const { data: events } = await github.rest.issues.listEvents({
+				...context.repo,
+				issue_number: id,
+				per_page    : 100,
+			})
+
+			const all = events.filter(v => v.event === "unlabeled" && v.label?.name === LABEL_NAME)
+			return all.length === 0 ? false : !all.at(-1).actor.login.endsWith("[bot]")
+		} catch (e) {
+			core.error(`Error checking label removal history: ${e.message}`)
+			return false
+		}
+	}
+
 	async function updateLabels(id, mark, body) {
 		try {
 			const marked = await hasLabel(id, LABEL_NAME)
-			if (mark && !marked) {
+
+			if (!mark && marked) {
+				await github.rest.issues.removeLabel({
+					...context.repo,
+					issue_number: id,
+					name        : LABEL_NAME,
+				})
+			} else if (mark && !marked && !await removedLabelManually(id)) {
 				await github.rest.issues.addLabels({
 					...context.repo,
 					issue_number: id,
@@ -75,12 +114,6 @@ module.exports = async ({ github, context, core }) => {
 					issue_number: id,
 					body,
 				})
-			} else if (!mark && marked) {
-				await github.rest.issues.removeLabel({
-					...context.repo,
-					issue_number: id,
-					name        : LABEL_NAME,
-				})
 			}
 		} catch (e) {
 			core.error(`Error updating labels: ${e.message}`)
@@ -99,7 +132,7 @@ module.exports = async ({ github, context, core }) => {
 			const twoDaysAgo = new Date(now - 2 * 24 * 60 * 60 * 1000)
 
 			for (const issue of issues) {
-				const markedAt = new Date(issue.labels_at || issue.created_at)
+				const markedAt = new Date(await lastLabeledAt(issue.number) || issue.created_at)
 				if (markedAt < twoDaysAgo) {
 					await github.rest.issues.update({
 						...context.repo,
