@@ -321,22 +321,22 @@ impl Kgp {
 
 		Adapter::Kgp.image_hide()?;
 		Adapter::shown_store(area);
-		Emulator::move_lock((area.x, area.y), |stderr| {
-			stderr.write_all(&b1)?;
-			stderr.write_all(&b2)?;
+		Emulator::move_lock((area.x, area.y), |w| {
+			w.write_all(&b1)?;
+			w.write_all(&b2)?;
 			Ok(area)
 		})
 	}
 
 	pub(crate) fn image_erase(area: Rect) -> Result<()> {
 		let s = " ".repeat(area.width as usize);
-		Emulator::move_lock((0, 0), |stderr| {
+		Emulator::move_lock((0, 0), |w| {
 			for y in area.top()..area.bottom() {
-				queue!(stderr, MoveTo(area.x, y))?;
-				write!(stderr, "{s}")?;
+				queue!(w, MoveTo(area.x, y))?;
+				write!(w, "{s}")?;
 			}
 
-			write!(stderr, "{START}_Gq=2,a=d,d=A{ESCAPE}\\{CLOSE}")?;
+			write!(w, "{START}_Gq=2,a=d,d=A{ESCAPE}\\{CLOSE}")?;
 			Ok(())
 		})
 	}
