@@ -2,7 +2,7 @@
 
 yazi_macro::mod_pub!(drivers);
 
-yazi_macro::mod_flat!(adapter brand dimension emulator image info mux stdin unknown);
+yazi_macro::mod_flat!(adapter brand dimension emulator image info mux unknown);
 
 use yazi_shared::{SyncCell, in_wsl};
 
