@@ -1,5 +1,7 @@
 use anyhow::Result;
 use tracing::error;
+use yazi_macro::time;
+use yazi_shared::tty::TTY;
 
 use crate::{CLOSE, ESCAPE, Emulator, START, TMUX};
 
@@ -18,14 +20,18 @@ impl Mux {
 	}
 
 	pub fn tmux_passthrough() {
-		let child = std::process::Command::new("tmux")
-			.args(["set", "-p", "allow-passthrough", "on"])
-			.stdin(std::process::Stdio::null())
-			.stdout(std::process::Stdio::null())
-			.stderr(std::process::Stdio::piped())
-			.spawn();
+		let output = time!(
+			"Running `tmux set -p allow-passthrough on`",
+			std::process::Command::new("tmux")
+				.args(["set", "-p", "allow-passthrough", "on"])
+				.stdin(std::process::Stdio::null())
+				.stdout(std::process::Stdio::null())
+				.stderr(std::process::Stdio::piped())
+				.spawn()
+				.and_then(|c| c.wait_with_output())
+		);
 
-		match child.and_then(|c| c.wait_with_output()) {
+		match output {
 			Ok(o) if o.status.success() => {}
 			Ok(o) => {
 				error!(
@@ -42,7 +48,7 @@ impl Mux {
 
 	pub fn tmux_drain() -> Result<()> {
 		if TMUX.get() {
-			crossterm::execute!(std::io::stderr(), crossterm::style::Print(Mux::csi("\x1b[5n")))?;
+			crossterm::execute!(TTY.writer(), crossterm::style::Print(Mux::csi("\x1b[5n")))?;
 			_ = Emulator::read_until_dsr();
 		}
 		Ok(())
@@ -68,9 +74,14 @@ impl Mux {
 		if !TMUX.get() {
 			return (term, program);
 		}
-		let Ok(output) = std::process::Command::new("tmux").arg("show-environment").output() else {
+
+		let Ok(output) = time!(
+			"Running `tmux show-environment`",
+			std::process::Command::new("tmux").arg("show-environment").output()
+		) else {
 			return (term, program);
 		};
+
 		for line in String::from_utf8_lossy(&output.stdout).lines() {
 			if let Some((k, v)) = line.trim().split_once('=') {
 				match k {
