@@ -1,17 +1,17 @@
-use yazi_config::PREVIEW;
+use yazi_config::YAZI;
 use yazi_fs::Xdg;
 
 use super::Actions;
 
 impl Actions {
 	pub(super) fn clear_cache() {
-		if PREVIEW.cache_dir == Xdg::cache_dir() {
-			println!("Clearing cache directory: \n{:?}", PREVIEW.cache_dir);
-			std::fs::remove_dir_all(&PREVIEW.cache_dir).unwrap();
+		if YAZI.preview.cache_dir == Xdg::cache_dir() {
+			println!("Clearing cache directory: \n{:?}", YAZI.preview.cache_dir);
+			std::fs::remove_dir_all(&YAZI.preview.cache_dir).unwrap();
 		} else {
 			println!(
 				"You've changed the default cache directory, for your data's safety, please clear it manually: \n{:?}",
-				PREVIEW.cache_dir
+				YAZI.preview.cache_dir
 			);
 		}
 	}
