@@ -1,19 +1,16 @@
+yazi_macro::mod_pub!(actions);
+
+yazi_macro::mod_flat!(args boot);
+
 use clap::Parser;
 use yazi_shared::RoCell;
 
-mod actions;
-mod args;
-mod boot;
-
-pub use args::*;
-pub use boot::*;
-
 pub static ARGS: RoCell<Args> = RoCell::new();
 pub static BOOT: RoCell<Boot> = RoCell::new();
 
 pub fn init() {
 	ARGS.with(<_>::parse);
-	BOOT.init(From::from(&*ARGS));
+	BOOT.init(<_>::from(&*ARGS));
 
 	actions::Actions::act(&ARGS);
 }
