@@ -69,9 +69,6 @@ pub(super) struct CommandPack {
 	/// Upgrade all packages.
 	#[arg(short = 'u', long)]
 	pub(super) upgrade: bool,
-	/// Migrate all packages.
-	#[arg(short = 'm', long)]
-	pub(super) migrate: bool, // TODO: remove this
 }
 
 #[derive(clap::Args)]
@@ -133,7 +130,10 @@ macro_rules! impl_emit_body {
 		impl $name {
 			#[allow(dead_code)]
 			pub(super) fn body(self) -> Result<String> {
-				Ok(serde_json::to_string(&(self.name, Cmd::parse_args(self.args.into_iter(), false)?))?)
+				Ok(serde_json::to_string(&(
+					self.name,
+					Cmd::parse_args(self.args.into_iter(), None, false)?,
+				))?)
 			}
 		}
 	};
