@@ -1,4 +1,4 @@
-use anyhow::{Context, Result};
+use anyhow::{Context, Result, bail};
 use tokio::fs;
 use twox_hash::XxHash3_128;
 use yazi_fs::ok_or_not_found;
@@ -22,18 +22,21 @@ impl Dependency {
 			&["LICENSE", "README.md", "main.lua"][..]
 		};
 
-		let mut hasher = XxHash3_128::new();
-		for file in files {
-			hasher.write(file.as_bytes());
-			hasher.write(b"VpvFw9Atb7cWGOdqhZCra634CcJJRlsRl72RbZeV0vpG1\0");
-			hasher.write(&ok_or_not_found(fs::read(dir.join(file)).await)?);
+		let mut h = XxHash3_128::new();
+		for &file in files {
+			h.write(file.as_bytes());
+			h.write(b"VpvFw9Atb7cWGOdqhZCra634CcJJRlsRl72RbZeV0vpG1\0");
+			h.write(&ok_or_not_found(fs::read(dir.join(file)).await)?);
 		}
 
 		let mut assets = vec![];
 		match fs::read_dir(dir.join("assets")).await {
 			Ok(mut it) => {
 				while let Some(entry) = it.next_entry().await? {
-					assets.push((entry.file_name(), fs::read(entry.path()).await?));
+					let Ok(name) = entry.file_name().into_string() else {
+						bail!("asset path is not valid UTF-8: {}", entry.path().display());
+					};
+					assets.push((name, fs::read(entry.path()).await?));
 				}
 			}
 			Err(e) if e.kind() == std::io::ErrorKind::NotFound => {}
@@ -42,11 +45,11 @@ impl Dependency {
 
 		assets.sort_unstable_by(|(a, _), (b, _)| a.cmp(b));
 		for (name, data) in assets {
-			hasher.write(name.as_encoded_bytes());
-			hasher.write(b"pQU2in0xcsu97Y77Nuq2LnT8mczMlFj22idcYRmMrglqU\0");
-			hasher.write(&data);
+			h.write(name.as_bytes());
+			h.write(b"pQU2in0xcsu97Y77Nuq2LnT8mczMlFj22idcYRmMrglqU\0");
+			h.write(&data);
 		}
 
-		Ok(format!("{:x}", hasher.finish_128()))
+		Ok(format!("{:x}", h.finish_128()))
 	}
 }
