@@ -5,12 +5,12 @@ use serde::{Deserialize, Deserializer, de::{self, Visitor}};
 use crate::pattern::Pattern;
 
 #[derive(Debug, Deserialize)]
-pub(super) struct OpenRule {
-	pub(super) name: Option<Pattern>,
-	pub(super) mime: Option<Pattern>,
+pub struct OpenRule {
+	pub name: Option<Pattern>,
+	pub mime: Option<Pattern>,
 	#[serde(rename = "use")]
 	#[serde(deserialize_with = "OpenRule::deserialize")]
-	pub(super) use_: Vec<String>,
+	pub use_: Vec<String>,
 }
 
 impl OpenRule {
@@ -39,7 +39,7 @@ impl OpenRule {
 			where
 				A: de::SeqAccess<'de>,
 			{
-				let mut uses = vec![];
+				let mut uses = Vec::with_capacity(seq.size_hint().unwrap_or(0));
 				while let Some(use_) = seq.next_element::<String>()? {
 					uses.push(use_);
 				}
