@@ -1,11 +1,9 @@
-use std::str::FromStr;
-
-use anyhow::Context;
 use serde::Deserialize;
+use yazi_codegen::DeserializeOver2;
 
 use super::{Offset, Origin};
 
-#[derive(Deserialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Confirm {
 	// trash
 	pub trash_title:  String,
@@ -30,22 +28,6 @@ pub struct Confirm {
 	pub quit_offset:  Offset,
 }
 
-impl FromStr for Confirm {
-	type Err = anyhow::Error;
-
-	fn from_str(s: &str) -> Result<Self, Self::Err> {
-		#[derive(Deserialize)]
-		struct Outer {
-			confirm: Confirm,
-		}
-
-		let outer = toml::from_str::<Outer>(s)
-			.context("Failed to parse the [confirm] section in your yazi.toml")?;
-
-		Ok(outer.confirm)
-	}
-}
-
 impl Confirm {
 	pub const fn border(&self) -> u16 { 2 }
 }
