@@ -1,13 +1,14 @@
-use std::{path::PathBuf, str::FromStr};
+use std::path::PathBuf;
 
-use anyhow::Context;
+use anyhow::{Result, bail};
 use serde::{Deserialize, Serialize};
-use validator::Validate;
+use yazi_codegen::{DeserializeOver1, DeserializeOver2};
+use yazi_fs::expand_path;
 use yazi_shared::theme::Style;
 
-use super::{Filetype, Flavor, Icons};
+use super::{Filetype, Flavor, Icon};
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver1, Serialize)]
 pub struct Theme {
 	pub flavor:  Flavor,
 	#[serde(rename = "manager")]
@@ -25,25 +26,13 @@ pub struct Theme {
 	pub help:    Help,
 
 	// File-specific styles
-	#[serde(rename = "filetype", deserialize_with = "Filetype::deserialize", skip_serializing)]
-	pub filetypes: Vec<Filetype>,
-	#[serde(rename = "icon", skip_serializing)]
-	pub icons:     Icons,
+	#[serde(skip_serializing)]
+	pub filetype: Filetype,
+	#[serde(skip_serializing)]
+	pub icon:     Icon,
 }
 
-impl FromStr for Theme {
-	type Err = anyhow::Error;
-
-	fn from_str(s: &str) -> Result<Self, Self::Err> {
-		let theme: Self = toml::from_str(s).context("Failed to parse your theme.toml")?;
-		theme.mgr.validate()?;
-		theme.which.validate()?;
-
-		Ok(theme)
-	}
-}
-
-#[derive(Deserialize, Serialize, Validate)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Mgr {
 	cwd: Style,
 
@@ -55,6 +44,9 @@ pub struct Mgr {
 	find_keyword:  Style,
 	find_position: Style,
 
+	// Symlink
+	symlink_target: Style,
+
 	// Marker
 	marker_copied:   Style,
 	marker_cut:      Style,
@@ -64,7 +56,6 @@ pub struct Mgr {
 	// Tab
 	tab_active:   Style,
 	tab_inactive: Style,
-	#[validate(range(min = 1, message = "Must be greater than 0"))]
 	tab_width:    u8,
 
 	// Count
@@ -80,7 +71,7 @@ pub struct Mgr {
 	pub syntect_theme: PathBuf,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Mode {
 	pub normal_main: Style,
 	pub normal_alt:  Style,
@@ -92,7 +83,7 @@ pub struct Mode {
 	pub unset_alt:  Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Status {
 	pub overall:   Style,
 	pub sep_left:  StatusSep,
@@ -111,15 +102,14 @@ pub struct Status {
 	pub progress_error:  Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct StatusSep {
 	pub open:  String,
 	pub close: String,
 }
 
-#[derive(Deserialize, Serialize, Validate)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Which {
-	#[validate(range(min = 1, max = 3, message = "Must be between 1 and 3"))]
 	pub cols: u8,
 	pub mask: Style,
 	pub cand: Style,
@@ -130,7 +120,7 @@ pub struct Which {
 	pub separator_style: Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Confirm {
 	pub border:  Style,
 	pub title:   Style,
@@ -142,7 +132,7 @@ pub struct Confirm {
 	pub btn_labels: [String; 2],
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Spot {
 	pub border: Style,
 	pub title:  Style,
@@ -151,7 +141,7 @@ pub struct Spot {
 	pub tbl_cell: Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Notify {
 	pub title_info:  Style,
 	pub title_warn:  Style,
@@ -162,14 +152,14 @@ pub struct Notify {
 	pub icon_error: String,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Pick {
 	pub border:   Style,
 	pub active:   Style,
 	pub inactive: Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Input {
 	pub border:   Style,
 	pub title:    Style,
@@ -177,7 +167,7 @@ pub struct Input {
 	pub selected: Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Cmp {
 	pub border:   Style,
 	pub active:   Style,
@@ -188,14 +178,14 @@ pub struct Cmp {
 	pub icon_command: String,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Tasks {
 	pub border:  Style,
 	pub title:   Style,
 	pub hovered: Style,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, DeserializeOver2, Serialize)]
 pub struct Help {
 	pub on:   Style,
 	pub run:  Style,
@@ -204,3 +194,20 @@ pub struct Help {
 	pub hovered: Style,
 	pub footer:  Style,
 }
+
+impl Theme {
+	pub(crate) fn reshape(mut self, light: bool) -> Result<Self> {
+		if self.mgr.tab_width < 1 {
+			bail!("[mgr].tab_width must be greater than 0");
+		} else if self.which.cols < 1 || self.which.cols > 3 {
+			bail!("[which].cols must be between 1 and 3");
+		}
+
+		self.icon = self.icon.reshape()?;
+
+		self.mgr.syntect_theme =
+			self.flavor.syntect_path(light).unwrap_or_else(|| expand_path(&self.mgr.syntect_theme));
+
+		Ok(self)
+	}
+}
