@@ -1,21 +1,22 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::confirm::Confirm;
 
-pub struct Opt {
+struct Opt {
 	submit: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { submit: c.bool("submit") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { submit: c.bool("submit") } }
 }
 impl From<bool> for Opt {
 	fn from(submit: bool) -> Self { Self { submit } }
 }
 
 impl Confirm {
-	pub fn close(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn close(&mut self, opt: Opt) {
 		if let Some(cb) = self.callback.take() {
 			_ = cb.send(opt.submit);
 		}
