@@ -1,16 +1,16 @@
 use std::path::MAIN_SEPARATOR;
 
 use crossterm::{execute, terminal::SetTitle};
-use yazi_config::MGR;
+use yazi_config::YAZI;
 use yazi_fs::CWD;
-use yazi_shared::event::CmdCow;
+use yazi_shared::{event::CmdCow, tty::TTY};
 
 use crate::{mgr::Mgr, tasks::Tasks};
 
 impl Mgr {
 	pub fn refresh(&mut self, _: CmdCow, tasks: &Tasks) {
-		if CWD.set(self.cwd()) && !MGR.title_format.is_empty() {
-			execute!(std::io::stderr(), SetTitle(self.title())).ok();
+		if CWD.set(self.cwd()) && !YAZI.mgr.title_format.is_empty() {
+			execute!(TTY.writer(), SetTitle(self.title())).ok();
 		}
 
 		self.active_mut().apply_files_attrs();
@@ -35,6 +35,6 @@ impl Mgr {
 			format!("{}", self.cwd().display())
 		};
 
-		MGR.title_format.replace("{cwd}", &cwd)
+		YAZI.mgr.title_format.replace("{cwd}", &cwd)
 	}
 }
