@@ -2,7 +2,7 @@ use std::time::Duration;
 
 use ratatui::layout::Rect;
 use yazi_macro::emit;
-use yazi_shared::{Layer, event::{Cmd, CmdCow, Data}};
+use yazi_shared::event::{Cmd, CmdCow, Data};
 
 use crate::notify::Notify;
 
@@ -69,7 +69,7 @@ impl Notify {
 
 		self.tick_handle = Some(tokio::spawn(async move {
 			tokio::time::sleep(interval).await;
-			emit!(Call(Cmd::args("update_notify", &[interval.as_secs_f64()]), Layer::App));
+			emit!(Call(Cmd::args("app:update_notify", &[interval.as_secs_f64()])));
 		}));
 	}
 }
