@@ -22,18 +22,6 @@ impl From<isize> for Opt {
 impl Tab {
 	#[yazi_codegen::command]
 	pub fn arrow(&mut self, opt: Opt) {
-		// TODO: remove this
-		if let Step::Fixed(n) = opt.step {
-			if n <= -999999 || n >= 999999 {
-				yazi_proxy::AppProxy::notify_warn(
-					"Deprecated command",
-					"`arrow -99999999` and `arrow 99999999` have been deprecated, please use `arrow top` and `arrow bot` instead.
-
-See #2294 for more details: https://github.com/sxyazi/yazi/pull/2294",
-				);
-			}
-		}
-
 		if !self.current.arrow(opt.step) {
 			return;
 		}
