@@ -16,8 +16,6 @@ yazi_macro::mod_flat!(
 	linemode
 	reveal
 	search
-	select
-	select_all
 	shell
 	sort
 	toggle
@@ -25,4 +23,5 @@ yazi_macro::mod_flat!(
 	update_peeked
 	update_spotted
 	visual_mode
+	follow,
 );
