@@ -1,22 +1,22 @@
 use std::collections::BTreeSet;
 
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::tab::{Mode, Tab};
 
-pub struct Opt {
+struct Opt {
 	unset: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { unset: c.named.contains_key("unset") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { unset: c.bool("unset") } }
 }
 
 impl Tab {
-	pub fn visual_mode(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn visual_mode(&mut self, opt: Opt) {
 		let idx = self.current.cursor;
-
 		if opt.unset {
 			self.mode = Mode::Unset(idx, BTreeSet::from([idx]));
 		} else {
