@@ -1,4 +1,4 @@
-use yazi_config::MGR;
+use yazi_config::YAZI;
 use yazi_fs::{FilesSorter, SortBy};
 
 #[derive(Clone, PartialEq)]
@@ -19,15 +19,15 @@ impl Default for Preference {
 	fn default() -> Self {
 		Self {
 			// Sorting
-			sort_by:        MGR.sort_by,
-			sort_sensitive: MGR.sort_sensitive,
-			sort_reverse:   MGR.sort_reverse,
-			sort_dir_first: MGR.sort_dir_first,
-			sort_translit:  MGR.sort_translit,
+			sort_by:        YAZI.mgr.sort_by,
+			sort_sensitive: YAZI.mgr.sort_sensitive,
+			sort_reverse:   YAZI.mgr.sort_reverse,
+			sort_dir_first: YAZI.mgr.sort_dir_first,
+			sort_translit:  YAZI.mgr.sort_translit,
 
 			// Display
-			linemode:    MGR.linemode.to_owned(),
-			show_hidden: MGR.show_hidden,
+			linemode:    YAZI.mgr.linemode.to_owned(),
+			show_hidden: YAZI.mgr.show_hidden,
 		}
 	}
 }
