@@ -85,29 +85,20 @@ impl Tab {
 		}
 	}
 
-	pub fn selected_or_hovered(&self, reorder: bool) -> Box<dyn Iterator<Item = &Url> + '_> {
+	pub fn selected_or_hovered(&self) -> Box<dyn Iterator<Item = &Url> + '_> {
 		if self.selected.is_empty() {
 			Box::new(self.hovered().map(|h| vec![&h.url]).unwrap_or_default().into_iter())
-		} else if !reorder {
-			Box::new(self.selected.keys())
 		} else {
-			let mut vec: Vec<_> = self.selected.iter().collect();
-			vec.sort_unstable_by(|(_, a), (_, b)| a.cmp(b));
-			Box::new(vec.into_iter().map(|(k, _)| k))
+			Box::new(self.selected.keys())
 		}
 	}
 
-	pub fn hovered_and_selected(&self, reorder: bool) -> Box<dyn Iterator<Item = &Url> + '_> {
+	pub fn hovered_and_selected(&self) -> Box<dyn Iterator<Item = &Url> + '_> {
 		let Some(h) = self.hovered() else { return Box::new(iter::empty()) };
-
 		if self.selected.is_empty() {
 			Box::new([&h.url, &h.url].into_iter())
-		} else if !reorder {
-			Box::new([&h.url].into_iter().chain(self.selected.keys()))
 		} else {
-			let mut vec: Vec<_> = self.selected.iter().collect();
-			vec.sort_unstable_by(|(_, a), (_, b)| a.cmp(b));
-			Box::new([&h.url].into_iter().chain(vec.into_iter().map(|(k, _)| k)))
+			Box::new([&h.url].into_iter().chain(self.selected.keys()))
 		}
 	}
 
@@ -123,22 +114,18 @@ impl Tab {
 				return render!();
 			}
 
-			let hovered = f.hovered().filter(|_| f.tracing).map(|h| h.urn_owned());
 			f.files.set_show_hidden(self.pref.show_hidden);
 			f.files.set_sorter(<_>::from(&self.pref));
 
 			render!(f.files.catchup_revision());
-			render!(f.repos(hovered.as_ref().map(|u| u.as_urn())));
+			render!(f.repos(f.trace.clone()));
 		};
 
 		apply(&mut self.current);
 
 		if let Some(parent) = &mut self.parent {
 			apply(parent);
-
-			// The parent should always track the CWD
-			parent.hover(self.current.url.urn());
-			parent.tracing = parent.hovered().map(|h| &h.url) == Some(&self.current.url);
+			parent.hover(self.current.url.urn()); // The parent should always track the CWD
 		}
 
 		self
