@@ -1,5 +1,3 @@
-use std::str::FromStr;
-
 use yazi_config::{KEYMAP, keymap::{Chord, Key}};
 use yazi_macro::render;
 use yazi_shared::{Layer, event::CmdCow};
@@ -8,7 +6,6 @@ use crate::which::{Which, WhichSorter};
 
 pub struct Opt {
 	cands:  Vec<Chord>,
-	layer:  Layer,
 	silent: bool,
 }
 
@@ -16,11 +13,7 @@ impl TryFrom<CmdCow> for Opt {
 	type Error = anyhow::Error;
 
 	fn try_from(mut c: CmdCow) -> Result<Self, Self::Error> {
-		Ok(Self {
-			cands:  c.take_any("candidates").unwrap_or_default(),
-			layer:  Layer::from_str(&c.take_str("layer").unwrap_or_default())?,
-			silent: c.bool("silent"),
-		})
+		Ok(Self { cands: c.take_any("candidates").unwrap_or_default(), silent: c.bool("silent") })
 	}
 }
 
@@ -34,7 +27,6 @@ impl Which {
 			return;
 		}
 
-		self.layer = opt.layer;
 		self.times = 0;
 		self.cands = opt.cands.into_iter().map(|c| c.into()).collect();
 
@@ -44,7 +36,6 @@ impl Which {
 	}
 
 	pub fn show_with(&mut self, key: Key, layer: Layer) {
-		self.layer = layer;
 		self.times = 1;
 		self.cands = KEYMAP
 			.get(layer)
