@@ -46,8 +46,8 @@ impl IntoLua for BodyMoveItem {
 	fn into_lua(self, lua: &Lua) -> mlua::Result<Value> {
 		lua
 			.create_table_from([
-				("from", lua.create_any_userdata(self.from)?),
-				("to", lua.create_any_userdata(self.to)?),
+				("from", yazi_binding::Url::new(self.from)),
+				("to", yazi_binding::Url::new(self.to)),
 			])?
 			.into_lua(lua)
 	}
