@@ -1,5 +1,5 @@
-use yazi_core::input::InputMode;
 use yazi_shared::{Layer, event::CmdCow};
+use yazi_widgets::input::InputMode;
 
 use crate::app::App;
 
@@ -97,6 +97,7 @@ impl<'a> Executor<'a> {
 		on!(ACTIVE, forward);
 		on!(ACTIVE, cd);
 		on!(ACTIVE, reveal);
+		on!(ACTIVE, follow);
 
 		// Toggle
 		on!(ACTIVE, toggle);
@@ -141,8 +142,6 @@ impl<'a> Executor<'a> {
 		on!(TABS, swap);
 
 		match cmd.name.as_str() {
-			// Tasks
-			"tasks_show" => self.app.cx.tasks.toggle(()),
 			// Help
 			"help" => self.app.cx.help.toggle(Layer::Mgr),
 			// Plugin
@@ -165,7 +164,8 @@ impl<'a> Executor<'a> {
 			};
 		}
 
-		on!(toggle, "close");
+		on!(show);
+		on!(close);
 		on!(arrow);
 		on!(inspect);
 		on!(cancel);
@@ -233,55 +233,30 @@ impl<'a> Executor<'a> {
 					return self.app.cx.input.$name(cmd);
 				}
 			};
-			($name:ident, $alias:literal) => {
-				if cmd.name == $alias {
-					return self.app.cx.input.$name(cmd);
-				}
-			};
 		}
 
+		on!(escape);
 		on!(show);
 		on!(close);
-		on!(escape);
-		on!(move_, "move");
-		on!(backward);
-		on!(forward);
-
-		if cmd.name.as_str() == "complete" {
-			return if cmd.bool("trigger") {
-				self.app.cx.cmp.trigger(cmd)
-			} else {
-				self.app.cx.input.complete(cmd)
-			};
-		}
 
 		match self.app.cx.input.mode() {
 			InputMode::Normal => {
-				on!(insert);
-				on!(visual);
-				on!(replace);
-
-				on!(delete);
-				on!(yank);
-				on!(paste);
-
-				on!(undo);
-				on!(redo);
-
 				match cmd.name.as_str() {
 					// Help
-					"help" => self.app.cx.help.toggle(Layer::Input),
+					"help" => return self.app.cx.help.toggle(Layer::Input),
 					// Plugin
-					"plugin" => self.app.plugin(cmd),
+					"plugin" => return self.app.plugin(cmd),
 					_ => {}
 				}
 			}
-			InputMode::Insert => {
-				on!(backspace);
-				on!(kill);
-			}
+			InputMode::Insert => match cmd.name.as_str() {
+				"complete" if cmd.bool("trigger") => return self.app.cx.cmp.trigger(cmd),
+				_ => {}
+			},
 			InputMode::Replace => {}
-		}
+		};
+
+		self.app.cx.input.execute(cmd)
 	}
 
 	fn confirm(&mut self, cmd: CmdCow) {
@@ -334,7 +309,6 @@ impl<'a> Executor<'a> {
 		on!(arrow);
 
 		match cmd.name.as_str() {
-			"close_input" => self.app.cx.input.close(cmd),
 			// Help
 			"help" => self.app.cx.help.toggle(Layer::Cmp),
 			// Plugin
