@@ -1,19 +1,22 @@
 use std::ops::{Deref, Range};
 
-use mlua::{AnyUserData, MetaMethod, UserData, UserDataFields, UserDataMethods};
+use mlua::{AnyUserData, MetaMethod, UserData, UserDataFields, UserDataMethods, Value};
+use yazi_binding::cached_field;
 
-use super::{File, Filter, Lives};
+use super::{File, Filter, Lives, PtrCell};
 
 pub(super) struct Files {
 	window: Range<usize>,
-	folder: *const yazi_core::tab::Folder,
-	tab:    *const yazi_core::tab::Tab,
+	folder: PtrCell<yazi_core::tab::Folder>,
+	tab:    PtrCell<yazi_core::tab::Tab>,
+
+	v_filter: Option<Value>,
 }
 
 impl Deref for Files {
 	type Target = yazi_fs::Files;
 
-	fn deref(&self) -> &Self::Target { &self.folder().files }
+	fn deref(&self) -> &Self::Target { &self.folder.files }
 }
 
 impl Files {
@@ -23,19 +26,13 @@ impl Files {
 		folder: &yazi_core::tab::Folder,
 		tab: &yazi_core::tab::Tab,
 	) -> mlua::Result<AnyUserData> {
-		Lives::scoped_userdata(Self { window, folder, tab })
+		Lives::scoped_userdata(Self { window, folder: folder.into(), tab: tab.into(), v_filter: None })
 	}
-
-	#[inline]
-	fn folder(&self) -> &yazi_core::tab::Folder { unsafe { &*self.folder } }
-
-	#[inline]
-	fn tab(&self) -> &yazi_core::tab::Tab { unsafe { &*self.tab } }
 }
 
 impl UserData for Files {
 	fn add_fields<F: UserDataFields<Self>>(fields: &mut F) {
-		fields.add_field_method_get("filter", |_, me| me.filter().map(Filter::make).transpose());
+		cached_field!(fields, filter, |_, me: &Self| me.filter().map(Filter::make).transpose());
 	}
 
 	fn add_methods<M: UserDataMethods<Self>>(methods: &mut M) {
@@ -46,7 +43,7 @@ impl UserData for Files {
 			if idx > me.window.end || idx == 0 {
 				Ok(None)
 			} else {
-				Some(File::make(idx - 1, me.folder(), me.tab())).transpose()
+				Some(File::make(idx - 1, &me.folder, &me.tab)).transpose()
 			}
 		});
 	}
