@@ -1,42 +1,44 @@
-use std::{io::{self, BufWriter, Stderr, stderr}, ops::{Deref, DerefMut}, sync::atomic::{AtomicBool, AtomicU8, Ordering}};
+use std::{io, ops::{Deref, DerefMut}, sync::atomic::{AtomicBool, AtomicU8, Ordering}};
 
 use anyhow::Result;
-use crossterm::{event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
+use crossterm::{Command, event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, style::Print, terminal::{LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
 use cursor::RestoreCursor;
 use ratatui::{CompletedFrame, Frame, Terminal, backend::CrosstermBackend, buffer::Buffer, layout::Rect};
 use yazi_adapter::{Emulator, Mux};
-use yazi_config::{INPUT, MGR};
+use yazi_config::YAZI;
+use yazi_shared::{SyncCell, tty::{TTY, TtyWriter}};
 
 static CSI_U: AtomicBool = AtomicBool::new(false);
 static BLINK: AtomicBool = AtomicBool::new(false);
 static SHAPE: AtomicU8 = AtomicU8::new(0);
 
 pub(super) struct Term {
-	inner:       Terminal<CrosstermBackend<BufWriter<Stderr>>>,
+	inner:       Terminal<CrosstermBackend<TtyWriter<'static>>>,
 	last_area:   Rect,
 	last_buffer: Buffer,
 }
 
 impl Term {
 	pub(super) fn start() -> Result<Self> {
+		static SKIP: SyncCell<bool> = SyncCell::new(false);
 		let mut term = Self {
-			inner:       Terminal::new(CrosstermBackend::new(BufWriter::new(stderr())))?,
+			inner:       Terminal::new(CrosstermBackend::new(TTY.writer()))?,
 			last_area:   Default::default(),
 			last_buffer: Default::default(),
 		};
 
 		enable_raw_mode()?;
-		if yazi_adapter::TMUX.get() {
+		if SKIP.replace(true) && yazi_adapter::TMUX.get() {
 			yazi_adapter::Mux::tmux_passthrough();
 		}
 
 		execute!(
-			BufWriter::new(stderr()),
+			TTY.writer(),
 			screen::SetScreen(true),
-			Print(Mux::csi("\x1bP$q q\x1b\\")), // Request cursor shape (DECRQSS query for DECSCUSR)
-			Print(Mux::csi("\x1b[?12$p")),      // Request cursor blink status (DECSET)
-			Print("\x1b[?u"),                   // Request keyboard enhancement flags (CSI u)
-			Print(Mux::csi("\x1b[0c")),         // Request device attributes
+			Print("\x1bP$q q\x1b\\"), // Request cursor shape (DECRQSS query for DECSCUSR)
+			Print(Mux::csi("\x1b[?12$p")), // Request cursor blink status (DECSET)
+			Print("\x1b[?u"),         // Request keyboard enhancement flags (CSI u)
+			Print(Mux::csi("\x1b[0c")), // Request device attributes
 			screen::SetScreen(false),
 			EnableBracketedPaste,
 			mouse::SetMouse(true),
@@ -57,13 +59,11 @@ impl Term {
 		);
 
 		if CSI_U.load(Ordering::Relaxed) {
-			queue!(
-				stderr(),
-				PushKeyboardEnhancementFlags(
-					KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES
-						| KeyboardEnhancementFlags::REPORT_ALTERNATE_KEYS
-				)
-			)?;
+			PushKeyboardEnhancementFlags(
+				KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES
+					| KeyboardEnhancementFlags::REPORT_ALTERNATE_KEYS,
+			)
+			.write_ansi(&mut TTY.writer())?;
 		}
 
 		term.hide_cursor()?;
@@ -74,11 +74,11 @@ impl Term {
 
 	fn stop(&mut self) -> Result<()> {
 		if CSI_U.swap(false, Ordering::Relaxed) {
-			execute!(stderr(), PopKeyboardEnhancementFlags)?;
+			PopKeyboardEnhancementFlags.write_ansi(&mut TTY.writer())?;
 		}
 
 		execute!(
-			stderr(),
+			TTY.writer(),
 			mouse::SetMouse(false),
 			RestoreCursor,
 			DisableBracketedPaste,
@@ -91,15 +91,15 @@ impl Term {
 
 	pub(super) fn goodbye(f: impl FnOnce() -> bool) -> ! {
 		if CSI_U.swap(false, Ordering::Relaxed) {
-			execute!(stderr(), PopKeyboardEnhancementFlags).ok();
+			PopKeyboardEnhancementFlags.write_ansi(&mut TTY.writer()).ok();
 		}
 
-		if !MGR.title_format.is_empty() {
-			execute!(stderr(), SetTitle("")).ok();
+		if !YAZI.mgr.title_format.is_empty() {
+			execute!(TTY.writer(), SetTitle("")).ok();
 		}
 
 		execute!(
-			stderr(),
+			TTY.writer(),
 			mouse::SetMouse(false),
 			RestoreCursor,
 			SetTitle(""),
@@ -141,36 +141,6 @@ impl Term {
 	pub(super) fn can_partial(&mut self) -> bool {
 		self.inner.autoresize().is_ok() && self.last_area == self.inner.get_frame().area()
 	}
-
-	#[inline]
-	pub(super) fn set_cursor_block() -> Result<()> {
-		use crossterm::cursor::SetCursorStyle;
-		Ok(if INPUT.cursor_blink {
-			queue!(stderr(), SetCursorStyle::BlinkingBlock)?
-		} else {
-			queue!(stderr(), SetCursorStyle::SteadyBlock)?
-		})
-	}
-
-	#[inline]
-	pub(super) fn set_cursor_bar() -> Result<()> {
-		use crossterm::cursor::SetCursorStyle;
-		Ok(if INPUT.cursor_blink {
-			queue!(stderr(), SetCursorStyle::BlinkingBar)?
-		} else {
-			queue!(stderr(), SetCursorStyle::SteadyBar)?
-		})
-	}
-
-	#[inline]
-	pub(super) fn set_cursor_underscore() -> Result<()> {
-		use crossterm::cursor::SetCursorStyle;
-		Ok(if INPUT.cursor_blink {
-			queue!(stderr(), SetCursorStyle::BlinkingUnderScore)?
-		} else {
-			queue!(stderr(), SetCursorStyle::SteadyUnderScore)?
-		})
-	}
 }
 
 impl Drop for Term {
@@ -178,7 +148,7 @@ impl Drop for Term {
 }
 
 impl Deref for Term {
-	type Target = Terminal<CrosstermBackend<BufWriter<Stderr>>>;
+	type Target = Terminal<CrosstermBackend<TtyWriter<'static>>>;
 
 	fn deref(&self) -> &Self::Target { &self.inner }
 }
@@ -190,13 +160,13 @@ impl DerefMut for Term {
 // --- Mouse support
 mod mouse {
 	use crossterm::event::{DisableMouseCapture, EnableMouseCapture};
-	use yazi_config::MGR;
+	use yazi_config::YAZI;
 
 	pub struct SetMouse(pub bool);
 
 	impl crossterm::Command for SetMouse {
 		fn write_ansi(&self, f: &mut impl std::fmt::Write) -> std::fmt::Result {
-			if MGR.mouse_events.is_empty() {
+			if YAZI.mgr.mouse_events.is_empty() {
 				Ok(())
 			} else if self.0 {
 				EnableMouseCapture.write_ansi(f)
@@ -207,7 +177,7 @@ mod mouse {
 
 		#[cfg(windows)]
 		fn execute_winapi(&self) -> std::io::Result<()> {
-			if MGR.mouse_events.is_empty() {
+			if YAZI.mgr.mouse_events.is_empty() {
 				Ok(())
 			} else if self.0 {
 				EnableMouseCapture.execute_winapi()
