@@ -2,7 +2,8 @@ use std::collections::{HashMap, HashSet};
 
 use yazi_shared::{Id, Ids, event::Cmd, url::{Url, UrnBuf}};
 
-use super::{Cha, File};
+use super::File;
+use crate::{cha::Cha, maybe_exists};
 
 pub static FILES_TICKET: Ids = Ids::new();
 
@@ -117,6 +118,17 @@ impl FilesOp {
 		}
 	}
 
+	pub async fn issue_error(cwd: &Url, kind: std::io::ErrorKind) {
+		use std::io::ErrorKind;
+		if kind != ErrorKind::NotFound {
+			Self::IOErr(cwd.clone(), kind).emit();
+		} else if maybe_exists(cwd).await {
+			Self::IOErr(cwd.clone(), kind).emit();
+		} else if let Some((p, n)) = cwd.pair() {
+			Self::Deleting(p, HashSet::from_iter([n])).emit();
+		}
+	}
+
 	pub fn diff_recoverable(&self, contains: impl Fn(&Url) -> bool) -> (Vec<Url>, Vec<Url>) {
 		match self {
 			Self::Deleting(cwd, urns) => (urns.iter().map(|u| cwd.join(u)).collect(), vec![]),
