@@ -29,9 +29,9 @@ function Progress:redraw()
 
 	local gauge = ui.Gauge():area(self._area)
 	if progress.fail == 0 then
-		gauge = gauge:gauge_style(THEME.status.progress_normal)
+		gauge = gauge:gauge_style(th.status.progress_normal)
 	else
-		gauge = gauge:gauge_style(THEME.status.progress_error)
+		gauge = gauge:gauge_style(th.status.progress_error)
 	end
 
 	local percent = 99
@@ -43,6 +43,6 @@ function Progress:redraw()
 	return {
 		gauge
 			:percent(percent)
-			:label(ui.Span(string.format("%3d%%, %d left", percent, left)):style(THEME.status.progress_label)),
+			:label(ui.Span(string.format("%3d%%, %d left", percent, left)):style(th.status.progress_label)),
 	}
 end
