@@ -24,24 +24,19 @@ function M:preload(job)
 		return true
 	end
 
-	local cmd = Command("magick"):args {
-		"-density",
-		200,
-		tostring(job.file.url),
-		"-flatten",
-		"-resize",
-		string.format("%dx%d^", rt.preview.max_width, rt.preview.max_height),
-		"-quality",
-		rt.preview.image_quality,
-		"-auto-orient",
-		"JPG:" .. tostring(cache),
-	}
-
-	if rt.tasks.image_alloc > 0 then
-		cmd = cmd:env("MAGICK_MEMORY_LIMIT", rt.tasks.image_alloc)
+	local cmd = M.with_env()
+	if job.args.flatten then
+		cmd = cmd:arg("-flatten")
 	end
 
-	local status, err = cmd:env("MAGICK_THREAD_LIMIT", 1):status()
+	-- stylua: ignore
+	local status, err = cmd:args {
+		tostring(job.file.url), "-auto-orient", "-strip",
+		"-sample", string.format("%dx%d>", rt.preview.max_width, rt.preview.max_height),
+		"-quality", rt.preview.image_quality,
+		string.format("JPG:%s", cache),
+	}:status()
+
 	if status then
 		return status.success
 	else
@@ -51,4 +46,12 @@ end
 
 function M:spot(job) require("file"):spot(job) end
 
+function M.with_env()
+	local cmd = Command("magick"):env("MAGICK_THREAD_LIMIT", 1)
+	if rt.tasks.image_alloc > 0 then
+		cmd = cmd:env("MAGICK_MEMORY_LIMIT", rt.tasks.image_alloc)
+	end
+	return cmd
+end
+
 return M
