@@ -9,15 +9,26 @@ pub struct Window {
 	pub height: u16,
 }
 
-impl Default for Window {
-	fn default() -> Self {
+impl Window {
+	pub fn get() -> Self {
 		let ws = Dimension::available();
 		Self { rows: ws.rows, cols: ws.columns, width: ws.width, height: ws.height }
 	}
 }
 
+impl From<Window> for crossterm::terminal::WindowSize {
+	fn from(value: Window) -> Self {
+		crossterm::terminal::WindowSize {
+			rows:    value.rows,
+			columns: value.cols,
+			width:   value.width,
+			height:  value.height,
+		}
+	}
+}
+
 impl UserData for Window {
-	fn add_fields<'lua, F: mlua::UserDataFields<'lua, Self>>(fields: &mut F) {
+	fn add_fields<F: mlua::UserDataFields<Self>>(fields: &mut F) {
 		fields.add_field_method_get("rows", |_, me| Ok(me.rows));
 		fields.add_field_method_get("cols", |_, me| Ok(me.cols));
 		fields.add_field_method_get("width", |_, me| Ok(me.width));
