@@ -55,13 +55,14 @@ impl Clipboard {
 
 	#[cfg(unix)]
 	pub async fn set(&self, s: impl AsRef<std::ffi::OsStr>) {
-		use std::{io::{BufWriter, stderr}, process::Stdio};
+		use std::process::Stdio;
 
 		use crossterm::execute;
 		use tokio::{io::AsyncWriteExt, process::Command};
+		use yazi_shared::tty::TTY;
 
 		s.as_ref().clone_into(&mut self.content.lock());
-		execute!(BufWriter::new(stderr()), osc52::SetClipboard::new(s.as_ref())).ok();
+		execute!(TTY.writer(), osc52::SetClipboard::new(s.as_ref())).ok();
 
 		let all = [
 			("pbcopy", &[][..]),
