@@ -1,7 +1,7 @@
 use std::mem;
 
 use ansi_to_tui::IntoText;
-use mlua::{AnyUserData, ExternalError, ExternalResult, FromLua, IntoLua, Lua, Table, UserData, UserDataMethods, Value};
+use mlua::{AnyUserData, ExternalError, ExternalResult, IntoLua, Lua, MetaMethod, Table, UserData, UserDataMethods, Value};
 use unicode_width::UnicodeWidthChar;
 
 use super::Span;
@@ -12,7 +12,6 @@ const RIGHT: u8 = 2;
 
 const EXPECTED: &str = "expected a string, Span, Line, or a table of them";
 
-#[derive(Clone, FromLua)]
 pub struct Line(pub(super) ratatui::text::Line<'static>);
 
 impl Line {
@@ -41,7 +40,7 @@ impl Line {
 			("RIGHT", RIGHT.into_lua(lua)?),
 		])?;
 
-		line.set_metatable(Some(lua.create_table_from([("__call", new)])?));
+		line.set_metatable(Some(lua.create_table_from([(MetaMethod::Call.name(), new)])?));
 		Ok(line)
 	}
 }
@@ -93,6 +92,10 @@ impl TryFrom<Table> for Line {
 	}
 }
 
+impl From<Line> for ratatui::text::Line<'static> {
+	fn from(value: Line) -> Self { value.0 }
+}
+
 impl UserData for Line {
 	fn add_methods<M: UserDataMethods<Self>>(methods: &mut M) {
 		crate::impl_style_method!(methods, 0.style);
