@@ -1,8 +1,10 @@
-use mlua::{AnyUserData, FromLua, Lua, Table, UserData};
+use mlua::{AnyUserData, ExternalError, Lua, MetaMethod, Table, UserData, Value};
 
 use super::Cell;
 
-#[derive(Clone, Debug, Default, FromLua)]
+const EXPECTED: &str = "expected a Row";
+
+#[derive(Clone, Debug, Default)]
 pub struct Row {
 	pub(super) cells: Vec<Cell>,
 	height:           u16,
@@ -18,7 +20,7 @@ impl Row {
 		})?;
 
 		let row = lua.create_table()?;
-		row.set_metatable(Some(lua.create_table_from([("__call", new)])?));
+		row.set_metatable(Some(lua.create_table_from([(MetaMethod::Call.name(), new)])?));
 
 		Ok(row)
 	}
@@ -34,6 +36,23 @@ impl From<Row> for ratatui::widgets::Row<'static> {
 	}
 }
 
+impl TryFrom<Value> for Row {
+	type Error = mlua::Error;
+
+	fn try_from(value: Value) -> Result<Self, Self::Error> {
+		Ok(match value {
+			Value::UserData(ud) => {
+				if let Ok(row) = ud.take() {
+					row
+				} else {
+					Err(EXPECTED.into_lua_err())?
+				}
+			}
+			_ => Err(EXPECTED.into_lua_err())?,
+		})
+	}
+}
+
 impl UserData for Row {
 	fn add_methods<M: mlua::UserDataMethods<Self>>(methods: &mut M) {
 		crate::impl_style_method!(methods, style);
