@@ -1,6 +1,6 @@
 use std::borrow::Cow;
 
-use mlua::{ExternalError, ExternalResult, HookTriggers, IntoLua, ObjectLike, Table, VmState};
+use mlua::{ExternalError, HookTriggers, IntoLua, ObjectLike, VmState};
 use tokio::{runtime::Handle, select};
 use tokio_util::sync::CancellationToken;
 use tracing::error;
@@ -17,19 +17,66 @@ pub fn peek(
 	file: yazi_fs::File,
 	mime: Cow<'static, str>,
 	skip: usize,
-) -> CancellationToken {
+) -> Option<CancellationToken> {
 	let ct = CancellationToken::new();
-	let (ct1, ct2) = (ct.clone(), ct.clone());
+	if let Some(c) = LOADER.read().get(&cmd.name) {
+		if c.sync_peek {
+			peek_sync(cmd, file, mime, skip);
+		} else {
+			peek_async(cmd, file, mime, skip, ct.clone());
+		}
+		return Some(ct).filter(|_| !c.sync_peek);
+	}
 
+	let ct_ = ct.clone();
+	tokio::spawn(async move {
+		select! {
+			_ = ct_.cancelled() => {},
+			Ok(b) = LOADER.ensure(&cmd.name, |c| c.sync_peek) => {
+				if b {
+					peek_sync(cmd, file, mime, skip);
+				} else {
+					peek_async(cmd, file, mime, skip, ct_);
+				}
+			},
+			else => {}
+		}
+	});
+
+	Some(ct)
+}
+
+fn peek_sync(cmd: &'static Cmd, file: yazi_fs::File, mime: Cow<'static, str>, skip: usize) {
+	let cb: PluginCallback = Box::new(move |lua, plugin| {
+		let job = lua.create_table_from([
+			("area", Rect::from(LAYOUT.get().preview).into_lua(lua)?),
+			("args", Sendable::args_to_table_ref(lua, &cmd.args)?.into_lua(lua)?),
+			("file", File::new(file).into_lua(lua)?),
+			("mime", mime.into_lua(lua)?),
+			("skip", skip.into_lua(lua)?),
+		])?;
+
+		plugin.call_method("peek", job)
+	});
+
+	AppProxy::plugin(PluginOpt::new_callback(&cmd.name, cb));
+}
+
+fn peek_async(
+	cmd: &'static Cmd,
+	file: yazi_fs::File,
+	mime: Cow<'static, str>,
+	skip: usize,
+	ct: CancellationToken,
+) {
+	let ct_ = ct.clone();
 	tokio::task::spawn_blocking(move || {
 		let future = async {
-			LOADER.ensure(&cmd.name).await.into_lua_err()?;
-
 			let lua = slim_lua(&cmd.name)?;
 			lua.set_hook(
 				HookTriggers::new().on_calls().on_returns().every_nth_instruction(2000),
 				move |_, dbg| {
-					if ct1.is_cancelled() && dbg.source().what != "C" {
+					if ct.is_cancelled() && dbg.source().what != "C" {
 						Err("Peek task cancelled".into_lua_err())
 					} else {
 						Ok(VmState::Continue)
@@ -37,26 +84,21 @@ pub fn peek(
 				},
 			);
 
-			let plugin: Table = if let Some(b) = LOADER.read().get(&cmd.name) {
-				lua.load(b.as_bytes()).set_name(&cmd.name).call(())?
-			} else {
-				return Err("unloaded plugin".into_lua_err());
-			};
-
+			let plugin = LOADER.load_once(&lua, &cmd.name)?;
 			let job = lua.create_table_from([
 				("area", Rect::from(LAYOUT.get().preview).into_lua(&lua)?),
 				("args", Sendable::args_to_table_ref(&lua, &cmd.args)?.into_lua(&lua)?),
-				("file", File(file).into_lua(&lua)?),
+				("file", File::new(file).into_lua(&lua)?),
 				("mime", mime.into_lua(&lua)?),
 				("skip", skip.into_lua(&lua)?),
 			])?;
 
-			if ct2.is_cancelled() { Ok(()) } else { plugin.call_async_method("peek", job).await }
+			if ct_.is_cancelled() { Ok(()) } else { plugin.call_async_method("peek", job).await }
 		};
 
 		let result = Handle::current().block_on(async {
 			select! {
-				_ = ct2.cancelled() => Ok(()),
+				_ = ct_.cancelled() => Ok(()),
 				r = future => r,
 			}
 		});
@@ -67,22 +109,4 @@ pub fn peek(
 			}
 		}
 	});
-
-	ct
-}
-
-pub fn peek_sync(cmd: &'static Cmd, file: yazi_fs::File, mime: Cow<'static, str>, skip: usize) {
-	let cb: PluginCallback = Box::new(move |lua, plugin| {
-		let job = lua.create_table_from([
-			("area", Rect::from(LAYOUT.get().preview).into_lua(lua)?),
-			("args", Sendable::args_to_table_ref(lua, &cmd.args)?.into_lua(lua)?),
-			("file", File(file).into_lua(lua)?),
-			("mime", mime.into_lua(lua)?),
-			("skip", skip.into_lua(lua)?),
-		])?;
-
-		plugin.call_method("peek", job)
-	});
-
-	AppProxy::plugin(PluginOpt::new_callback(&cmd.name, cb));
 }
