@@ -8,7 +8,7 @@ use crate::{elements::Rect, file::File};
 pub fn seek_sync(cmd: &'static Cmd, file: yazi_fs::File, units: i16) {
 	let cb: PluginCallback = Box::new(move |lua, plugin| {
 		let job = lua.create_table_from([
-			("file", File(file).into_lua(lua)?),
+			("file", File::new(file).into_lua(lua)?),
 			("area", Rect::from(LAYOUT.get().preview).into_lua(lua)?),
 			("units", units.into_lua(lua)?),
 		])?;
