@@ -1,13 +1,15 @@
-use std::process::Stdio;
+use std::{io, process::Stdio};
 
 use mlua::{AnyUserData, ExternalError, IntoLuaMulti, Lua, MetaMethod, Table, UserData, Value};
 use tokio::process::{ChildStderr, ChildStdin, ChildStdout};
+use yazi_binding::Error;
 
 use super::{Child, output::Output};
-use crate::{Error, process::Status};
+use crate::process::Status;
 
 pub struct Command {
-	inner: tokio::process::Command,
+	inner:  tokio::process::Command,
+	memory: Option<usize>,
 }
 
 const NULL: u8 = 0;
@@ -20,7 +22,7 @@ impl Command {
 			let mut inner = tokio::process::Command::new(program);
 			inner.kill_on_drop(true).stdin(Stdio::null()).stdout(Stdio::null()).stderr(Stdio::null());
 
-			Ok(Self { inner })
+			Ok(Self { inner, memory: None })
 		})?;
 
 		let command = lua.create_table_from([
@@ -34,6 +36,74 @@ impl Command {
 
 		lua.globals().raw_set("Command", command)
 	}
+
+	#[cfg(unix)]
+	fn spawn(&mut self) -> io::Result<Child> {
+		if let Some(max) = self.memory {
+			unsafe {
+				self.inner.pre_exec(move || {
+					let rlp = libc::rlimit { rlim_cur: max as _, rlim_max: max as _ };
+					libc::setrlimit(libc::RLIMIT_AS, &rlp);
+					Ok(())
+				});
+			}
+		}
+		self.inner.spawn().map(Child::new)
+	}
+
+	#[cfg(windows)]
+	fn spawn(&mut self) -> io::Result<Child> {
+		use std::os::windows::io::RawHandle;
+
+		use windows_sys::Win32::System::JobObjects::{AssignProcessToJobObject, CreateJobObjectW, JOB_OBJECT_LIMIT_PROCESS_MEMORY, JOBOBJECT_EXTENDED_LIMIT_INFORMATION, JobObjectExtendedLimitInformation, SetInformationJobObject};
+
+		fn assign_job(max: usize, handle: RawHandle) -> io::Result<RawHandle> {
+			unsafe {
+				let job = CreateJobObjectW(std::ptr::null_mut(), std::ptr::null());
+				if job.is_null() {
+					return Err(io::Error::last_os_error());
+				}
+
+				let mut info: JOBOBJECT_EXTENDED_LIMIT_INFORMATION = std::mem::zeroed();
+				info.BasicLimitInformation.LimitFlags = JOB_OBJECT_LIMIT_PROCESS_MEMORY;
+				info.ProcessMemoryLimit = max;
+
+				let result = SetInformationJobObject(
+					job,
+					JobObjectExtendedLimitInformation,
+					&mut info as *mut _ as *mut _,
+					std::mem::size_of_val(&info) as u32,
+				);
+
+				if result == 0 {
+					Err(io::Error::last_os_error())
+				} else if AssignProcessToJobObject(job, handle) == 0 {
+					Err(io::Error::last_os_error())
+				} else {
+					Ok(job)
+				}
+			}
+		}
+
+		let child = self.inner.spawn()?;
+		if let (Some(max), Some(handle)) = (self.memory, child.raw_handle()) {
+			if let Ok(job) = assign_job(max, handle) {
+				return Ok(Child::new(child, Some(job)));
+			}
+		}
+
+		Ok(Child::new(child, None))
+	}
+
+	async fn output(&mut self) -> io::Result<std::process::Output> {
+		self.inner.stdin(Stdio::piped());
+		self.inner.stdout(Stdio::piped());
+		self.spawn()?.wait_with_output().await
+	}
+
+	async fn status(&mut self) -> io::Result<std::process::ExitStatus> {
+		self.spawn()?.status().await
+	}
 }
 
 impl UserData for Command {
@@ -101,18 +171,22 @@ impl UserData for Command {
 			ud.borrow_mut::<Self>()?.inner.stderr(make_stdio(stdio)?);
 			Ok(ud)
 		});
-		methods.add_method_mut("spawn", |lua, me, ()| match me.inner.spawn() {
-			Ok(child) => (Child::new(child), Value::Nil).into_lua_multi(lua),
+		methods.add_function_mut("memory", |_, (ud, max): (AnyUserData, usize)| {
+			ud.borrow_mut::<Self>()?.memory = Some(max);
+			Ok(ud)
+		});
+		methods.add_method_mut("spawn", |lua, me, ()| match me.spawn() {
+			Ok(child) => (child, Value::Nil).into_lua_multi(lua),
 			Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(lua),
 		});
 		methods.add_async_method_mut("output", |lua, mut me, ()| async move {
-			match me.inner.output().await {
+			match me.output().await {
 				Ok(output) => (Output::new(output), Value::Nil).into_lua_multi(&lua),
 				Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
 		methods.add_async_method_mut("status", |lua, mut me, ()| async move {
-			match me.inner.status().await {
+			match me.status().await {
 				Ok(status) => (Status::new(status), Value::Nil).into_lua_multi(&lua),
 				Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 			}
