@@ -1,5 +1,5 @@
 use mlua::{AnyUserData, Function, IntoLuaMulti, Lua, Table, Value};
-use yazi_config::{PREVIEW, preview::PreviewWrap};
+use yazi_config::{YAZI, preview::PreviewWrap};
 use yazi_macro::emit;
 use yazi_shared::{errors::PeekError, event::Cmd};
 
@@ -9,7 +9,7 @@ use crate::{elements::{Area, Rect, Renderable, Text, WRAP, WRAP_NO}, external::H
 #[derive(Debug, Default)]
 pub struct PreviewLock {
 	pub url:  yazi_shared::url::Url,
-	pub cha:  yazi_fs::Cha,
+	pub cha:  yazi_fs::cha::Cha,
 	pub mime: String,
 
 	pub skip: usize,
@@ -51,7 +51,8 @@ impl Utils {
 			lock.data = vec![Renderable::Text(Text {
 				area,
 				inner,
-				wrap: if PREVIEW.wrap == PreviewWrap::Yes { WRAP } else { WRAP_NO },
+				wrap: if YAZI.preview.wrap == PreviewWrap::Yes { WRAP } else { WRAP_NO },
+				scroll: Default::default(),
 			})];
 
 			emit!(Call(Cmd::new("mgr:update_peeked").with_any("lock", lock)));
