@@ -8,6 +8,7 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 	Composer::make(lua, 45, move |lua, key| {
 		match key {
 			// App
+			b"id" => Utils::id(lua)?,
 			b"hide" => Utils::hide(lua)?,
 
 			// Cache
@@ -44,6 +45,9 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			b"preview_code" => Utils::preview_code(lua)?,
 			b"preview_widgets" => Utils::preview_widgets(lua)?,
 
+			// Process
+			b"proc_info" => Utils::proc_info(lua)?,
+
 			// Spot
 			b"spot_table" => Utils::spot_table(lua)?,
 			b"spot_widgets" => Utils::spot_widgets(lua)?,
@@ -59,7 +63,6 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			b"target_family" => Utils::target_family(lua)?,
 
 			// Text
-			b"md5" => Utils::hash(lua, true)?, // TODO: deprecate this in the future
 			b"hash" => Utils::hash(lua, false)?,
 			b"quote" => Utils::quote(lua)?,
 			b"truncate" => Utils::truncate(lua)?,
