@@ -1,7 +1,7 @@
 use tokio::sync::mpsc;
 use yazi_config::popup::InputCfg;
 use yazi_macro::emit;
-use yazi_shared::{Layer, errors::InputError, event::Cmd};
+use yazi_shared::{errors::InputError, event::Cmd};
 
 pub struct InputProxy;
 
@@ -9,12 +9,12 @@ impl InputProxy {
 	#[inline]
 	pub fn show(cfg: InputCfg) -> mpsc::UnboundedReceiver<Result<String, InputError>> {
 		let (tx, rx) = mpsc::unbounded_channel();
-		emit!(Call(Cmd::new("show").with_any("tx", tx).with_any("cfg", cfg), Layer::Input));
+		emit!(Call(Cmd::new("input:show").with_any("tx", tx).with_any("cfg", cfg)));
 		rx
 	}
 
 	#[inline]
 	pub fn complete(word: &str, ticket: usize) {
-		emit!(Call(Cmd::args("complete", &[word]).with("ticket", ticket), Layer::Input));
+		emit!(Call(Cmd::args("input:complete", &[word]).with("ticket", ticket)));
 	}
 }
