@@ -1,14 +1,15 @@
 use std::{borrow::Cow, ffi::OsString};
 
 use tokio::sync::oneshot;
-use yazi_config::open::Opener;
-use yazi_shared::event::CmdCow;
+use yazi_config::opener::OpenerRule;
+use yazi_shared::{event::CmdCow, url::Url};
 
 // --- Exec
 pub struct ProcessExecOpt {
+	pub cwd:    Url,
+	pub opener: Cow<'static, OpenerRule>,
 	pub args:   Vec<OsString>,
-	pub opener: Cow<'static, Opener>,
-	pub done:   oneshot::Sender<()>,
+	pub done:   Option<oneshot::Sender<()>>,
 }
 
 impl TryFrom<CmdCow> for ProcessExecOpt {
