@@ -1,7 +1,7 @@
 use std::sync::Arc;
 
-use yazi_config::plugin::{FetcherProps, PreloaderProps};
-use yazi_shared::{fs::Url, Throttle};
+use yazi_config::plugin::{Fetcher, Preloader};
+use yazi_shared::{Throttle, url::Url};
 
 #[derive(Debug)]
 pub enum PreworkOp {
@@ -20,18 +20,18 @@ impl PreworkOp {
 	}
 }
 
-#[derive(Clone, Debug)]
+#[derive(Debug)]
 pub struct PreworkOpFetch {
 	pub id:      usize,
-	pub plugin:  FetcherProps,
-	pub targets: Vec<yazi_shared::fs::File>,
+	pub plugin:  &'static Fetcher,
+	pub targets: Vec<yazi_fs::File>,
 }
 
 #[derive(Clone, Debug)]
 pub struct PreworkOpLoad {
 	pub id:     usize,
-	pub plugin: PreloaderProps,
-	pub target: yazi_shared::fs::File,
+	pub plugin: &'static Preloader,
+	pub target: yazi_fs::File,
 }
 
 #[derive(Debug)]
