@@ -1,8 +1,8 @@
-use std::{any::Any, collections::HashMap};
+use std::{any::Any, borrow::Cow, collections::HashMap};
 
-use serde::{Deserialize, Serialize};
+use serde::{Deserialize, Serialize, de};
 
-use crate::{fs::Url, OrderedFloat};
+use crate::{OrderedFloat, url::Url};
 
 // --- Data
 #[derive(Debug, Serialize, Deserialize)]
@@ -18,7 +18,9 @@ pub enum Data {
 	#[serde(skip_deserializing)]
 	Url(Url),
 	#[serde(skip)]
-	Any(Box<dyn Any + Send>),
+	Bytes(Vec<u8>),
+	#[serde(skip)]
+	Any(Box<dyn Any + Send + Sync>),
 }
 
 impl Data {
@@ -40,14 +42,6 @@ impl Data {
 		}
 	}
 
-	#[inline]
-	pub fn as_any<T: 'static>(&self) -> Option<&T> {
-		match self {
-			Self::Any(b) => b.downcast_ref::<T>(),
-			_ => None,
-		}
-	}
-
 	#[inline]
 	pub fn into_any<T: 'static>(self) -> Option<T> {
 		match self {
@@ -65,7 +59,7 @@ impl Data {
 		}
 	}
 
-	pub fn into_dict_string(self) -> HashMap<String, String> {
+	pub fn into_dict_string(self) -> HashMap<Cow<'static, str>, String> {
 		let Self::Dict(dict) = self else {
 			return Default::default();
 		};
@@ -80,10 +74,10 @@ impl Data {
 	}
 
 	#[inline]
-	pub fn shallow_clone(&self) -> Option<Self> {
+	pub fn to_url(&self) -> Option<Url> {
 		match self {
-			Self::Boolean(b) => Some(Self::Boolean(*b)),
-			Self::String(s) => Some(Self::String(s.clone())),
+			Self::String(s) => Some(Url::from(s)),
+			Self::Url(u) => Some(u.clone()),
 			_ => None,
 		}
 	}
@@ -95,9 +89,10 @@ impl Data {
 pub enum DataKey {
 	Nil,
 	Boolean(bool),
+	#[serde(deserialize_with = "Self::deserialize_integer")]
 	Integer(i64),
 	Number(OrderedFloat),
-	String(String),
+	String(Cow<'static, str>),
 	#[serde(skip_deserializing)]
 	Url(Url),
 }
@@ -105,6 +100,52 @@ pub enum DataKey {
 impl DataKey {
 	#[inline]
 	pub fn is_integer(&self) -> bool { matches!(self, Self::Integer(_)) }
+
+	#[inline]
+	pub fn as_str(&self) -> Option<&str> {
+		match self {
+			Self::String(s) => Some(s),
+			_ => None,
+		}
+	}
+
+	fn deserialize_integer<'de, D>(deserializer: D) -> Result<i64, D::Error>
+	where
+		D: de::Deserializer<'de>,
+	{
+		struct Visitor;
+
+		impl de::Visitor<'_> for Visitor {
+			type Value = i64;
+
+			fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+				formatter.write_str("an integer or a string of an integer")
+			}
+
+			fn visit_i64<E>(self, value: i64) -> Result<i64, E> { Ok(value) }
+
+			fn visit_str<E>(self, value: &str) -> Result<i64, E>
+			where
+				E: de::Error,
+			{
+				value.parse().map_err(de::Error::custom)
+			}
+		}
+
+		deserializer.deserialize_any(Visitor)
+	}
+}
+
+impl From<usize> for DataKey {
+	fn from(value: usize) -> Self { Self::Integer(value as i64) }
+}
+
+impl From<&'static str> for DataKey {
+	fn from(value: &'static str) -> Self { Self::String(Cow::Borrowed(value)) }
+}
+
+impl From<String> for DataKey {
+	fn from(value: String) -> Self { Self::String(Cow::Owned(value)) }
 }
 
 // --- Macros
@@ -143,3 +184,5 @@ impl_integer_as!(isize, as_isize);
 impl_integer_as!(i16, as_i16);
 
 impl_number_as!(f64, as_f64);
+
+impl_integer_as!(crate::Id, as_id);
